==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/pt_BR.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privacidade",
    "-" : "-",
    "Add external admin" : "Adicionar administrador externo",
    "Your files are not protected by encryption." : "Seus arquivos não estão criptografados.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Seus arquivos estão criptografados com {linkopen}criptografia-lado-do-servidor ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Este servidor está protegido com criptografia-de-disco-completo.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Seus arquivos estão criptografados com {linkopen}criptografia-lado-do-servidor ↗{linkclose}. Adicionalmente, este servidor está protegido com criptografia-de-disco-completo.",
    "This server is using full-disk-encryption." : "Este servidor está usando criptografia-de-disco-completo.",
    "Your data is located in: " : "Seus dados estão em:",
    "The admin hasn't selected the location of the server yet." : "O administrador ainda não selecionou a localização do servidor.",
    "Please select a country" : "Selecione um país",
    "You don't have any shares with individual users." : "Você não tem compartilhamentos com usuários individuais.",
    "Somaliland" : "Somalilândia",
    "United Arab Emirates" : "Emirados Árabes Unidos",
    "Afghanistan" : "Afeganistão",
    "Albania" : "Albânia",
    "Armenia" : "Armênia",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Áustria",
    "Australia" : "Austrália",
    "Azerbaijan" : "Azerbaijão",
    "Bosnia and Herzegowina" : "Bósnia e Herzegovina",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bélgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgária",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolívia",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Butão",
    "Botswana" : "Botsuana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Canadá",
    "Democratic Republic of the Congo" : "República Democrática do Congo",
    "Central African Republic" : "República Centro-Africana",
    "Congo" : "Congo",
    "Switzerland" : "Suíça",
    "Cote d'Ivoire" : "Costa do Marfim",
    "Chile" : "Chile",
    "Cameroon" : "Camarões",
    "China" : "China",
    "Colombia" : "Colômbia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cyprus" : "Chipre",
    "Czech" : "Tcheca",
    "Germany" : "Alemanha",
    "Djibouti" : "Djibuti",
    "Denmark" : "Dinamarca",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Algéria",
    "Ecuador" : "Equador",
    "Estonia" : "Estônia",
    "Egypt" : "Egito",
    "West Sahara" : "Saara Ocidental",
    "Eritrea" : "Eritréia",
    "Spain" : "Espanha",
    "Ethiopia" : "Etiópia",
    "Finland" : "Finlândia",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Ilhas Falkland",
    "France" : "França",
    "Gabon" : "Gabão",
    "United Kingdom" : "Reino Unido",
    "Georgia" : "Georgia",
    "Ghana" : "Gana",
    "Greenland" : "Groenlândia",
    "Gambia" : "Gâmbia",
    "Guinea" : "Guiné",
    "Equatorial Guinea" : "Guiné Equatorial",
    "Greece" : "Grécia",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Guiné-Bissau",
    "Guyana" : "Guiana",
    "Honduras" : "Honduras",
    "Croatia" : "Croácia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungria",
    "Indonesia" : "Indonésia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "India" : "Índia",
    "Iraq" : "Iraque",
    "Iran" : "Irã",
    "Iceland" : "Islândia",
    "Italy" : "Itália",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordânia",
    "Japan" : "Japão",
    "Kenya" : "Quênia",
    "Kyrgyzstan" : "Quirguistão",
    "Cambodia" : "Camboja",
    "North Korea" : "Coreia do Norte",
    "South Korea" : "Coreia do Sul",
    "Kuwait" : "Kuwait",
    "Kazakhstan" : "Cazaquistão",
    "Laos" : "Laos",
    "Lebanon" : "Líbano",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Libéria",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituânia",
    "Luxembourg" : "Luxemburgo",
    "Latvia" : "Letônia",
    "Libya" : "Líbia",
    "Morocco" : "Marrocos",
    "Moldova" : "Moldávia",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagascar",
    "Macedonia" : "Macedônia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongólia",
    "Mauritania" : "Mauritânia",
    "Malawi" : "Malawi",
    "Mexico" : "México",
    "Malaysia" : "Malásia",
    "Mozambique" : "Moçambique",
    "Namibia" : "Namíbia",
    "New Caledonia" : "Nova Caledônia",
    "Niger" : "Nigéria",
    "Nigeria" : "Nigéria",
    "Nicaragua" : "Nicarágua",
    "Netherlands" : "Holanda",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "New Zealand" : "Nova Zelândia",
    "Oman" : "Omã",
    "Panama" : "Panamá",
    "Peru" : "Peru",
    "Papua New Guinea" : "Papua Nova Guiné",
    "Philippines" : "Filipinas",
    "Pakistan" : "Paquistão",
    "Poland" : "Polônia",
    "Puerto Rico" : "Porto Rico",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguai",
    "Qatar" : "Catar",
    "Romania" : "Romênia",
    "Serbia" : "Sérvia",
    "Russia" : "Rússia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arábia Saudita",
    "Solomon Islands" : "Ilhas Salomão",
    "Sudan" : "Sudão",
    "Sweden" : "Suécia",
    "Singapore" : "Cingapura",
    "Slovenia" : "Eslovênia",
    "Slovakia" : "Eslováquia",
    "Sierra Leone" : "Serra Leoa",
    "Senegal" : "Senegal",
    "Somalia" : "Somália",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudão do Sul",
    "El Salvador" : "El Salvador",
    "Syria" : "Síria",
    "Swaziland" : "Suazilândia",
    "Chad" : "Chade",
    "Fr. S. Antarctic Lands" : "Fr. S. Terras Antárticas",
    "Togo" : "Togo",
    "Thailand" : "Tailândia",
    "Tajikistan" : "Tajiquistão",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turcomenistão",
    "Tunisia" : "Tunísia",
    "Turkey" : "Turquia",
    "Trinidad and Tobago" : "Trinidade e Tobago",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzânia",
    "Ukraine" : "Ucrânia",
    "Uganda" : "Uganda",
    "United States" : "Estados Unidos",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Uzbequistão",
    "Venezuela" : "Venezuela",
    "Vietnam" : "Vietnã",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Iêmen",
    "South Africa" : "África do Sul",
    "Zambia" : "Zâmbia",
    "Zimbabwe" : "Zimbábue",
    "Your Nextcloud account" : "Sua conta Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Seus dados representam quem você é e podem ser facilmente usados. Na Nextcloud acreditamos que você tem o direito de decidir o que acontece com eles. O Nextcloud protege seus direitos conforme definido no Manifesto de Dados do Usuário!",
    "User Data Manifesto 2.0" : "Manifesto de Dados do Usuário 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definindo direitos básicos para as pessoas controlarem seus próprios dados na era da internet",
    "Control" : "Controle",
    "over user data access" : "sobre o acesso a dados do usuário",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Os dados carregados explicitamente e de bom grado por um usuário devem estar sob o controle final dele. Os usuários podem decidir quem tem acesso direto aos dados e com quais permissões e licenças esse acesso deve ser concedido.",
    "Knowledge" : "Conhecimento",
    "of how the data is stored" : "de como os dados são armazenados",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Quando os dados são carregados em um provedor de serviços específico, os usuários devem ser informados sobre onde ele armazena os dados, por quanto tempo, em qual jurisdição o provedor de serviços específico opera e quais leis se aplicam.",
    "Freedom" : "Liberdade",
    "to choose a platform" : "escolher uma plataforma",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Os usuários podem extrair seus dados do serviço a qualquer momento sem qualquer bloqueio do fornecedor. Padrões abertos para formatos e protocolos são necessários para garantir isso.",
    "Learn more ↗" : "Saiba mais ↗",
    "Where is your data?" : "Onde estão seus dados?",
    "Who has access to your data?" : "Quem tem acesso aos seus dados?",
    "Administrators" : "Administradores",
    "People you shared with" : "Pessoas com quem você compartilhou",
    "Privacy policy" : "Política de privacidade",
    "Read the privacy policy." : "Leia a política de privacidade.",
    "Encryption" : "Criptografia"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-17.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/pt_BR.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privacidade",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "O centro de privacidade mostra onde seus dados estão armazenados e quem pode acessá-los, seja porque você compartilhou com eles ou porque são administradores.",
    "Add external admin" : "Adicionar administrador externo",
    "Your files are not protected by encryption." : "Seus arquivos não estão criptografados.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Seus arquivos estão criptografados com {linkopen}criptografia-lado-do-servidor ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Este servidor está protegido com criptografia-de-disco-completo.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Seus arquivos estão criptografados com {linkopen}criptografia-lado-do-servidor ↗{linkclose}. Adicionalmente, este servidor está protegido com criptografia-de-disco-completo.",
    "This server is using full-disk-encryption." : "Este servidor está usando criptografia-de-disco-completo.",
    "Your data is located in: " : "Seus dados estão em:",
    "The admin hasn't selected the location of the server yet." : "O administrador ainda não selecionou a localização do servidor.",
    "Please select a country" : "Selecione um país",
    "You don't have any shares with individual users." : "Você não tem compartilhamentos com usuários individuais.",
    "Somaliland" : "Somalilândia",
    "United Arab Emirates" : "Emirados Árabes Unidos",
    "Afghanistan" : "Afeganistão",
    "Albania" : "Albânia",
    "Armenia" : "Armênia",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Áustria",
    "Australia" : "Austrália",
    "Azerbaijan" : "Azerbaijão",
    "Bosnia and Herzegowina" : "Bósnia e Herzegovina",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bélgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgária",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolívia",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Butão",
    "Botswana" : "Botsuana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Canadá",
    "Democratic Republic of the Congo" : "República Democrática do Congo",
    "Central African Republic" : "República Centro-Africana",
    "Congo" : "Congo",
    "Switzerland" : "Suíça",
    "Cote d'Ivoire" : "Costa do Marfim",
    "Chile" : "Chile",
    "Cameroon" : "Camarões",
    "China" : "China",
    "Colombia" : "Colômbia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cyprus" : "Chipre",
    "Czech" : "Tcheca",
    "Germany" : "Alemanha",
    "Djibouti" : "Djibuti",
    "Denmark" : "Dinamarca",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Algéria",
    "Ecuador" : "Equador",
    "Estonia" : "Estônia",
    "Egypt" : "Egito",
    "West Sahara" : "Saara Ocidental",
    "Eritrea" : "Eritréia",
    "Spain" : "Espanha",
    "Ethiopia" : "Etiópia",
    "Finland" : "Finlândia",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Ilhas Falkland",
    "France" : "França",
    "Gabon" : "Gabão",
    "United Kingdom" : "Reino Unido",
    "Georgia" : "Georgia",
    "Ghana" : "Gana",
    "Greenland" : "Groenlândia",
    "Gambia" : "Gâmbia",
    "Guinea" : "Guiné",
    "Equatorial Guinea" : "Guiné Equatorial",
    "Greece" : "Grécia",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Guiné-Bissau",
    "Guyana" : "Guiana",
    "Honduras" : "Honduras",
    "Croatia" : "Croácia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungria",
    "Indonesia" : "Indonésia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "India" : "Índia",
    "Iraq" : "Iraque",
    "Iran" : "Irã",
    "Iceland" : "Islândia",
    "Italy" : "Itália",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordânia",
    "Japan" : "Japão",
    "Kenya" : "Quênia",
    "Kyrgyzstan" : "Quirguistão",
    "Cambodia" : "Camboja",
    "North Korea" : "Coreia do Norte",
    "South Korea" : "Coreia do Sul",
    "Kuwait" : "Kuwait",
    "Kazakhstan" : "Cazaquistão",
    "Laos" : "Laos",
    "Lebanon" : "Líbano",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Libéria",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituânia",
    "Luxembourg" : "Luxemburgo",
    "Latvia" : "Letônia",
    "Libya" : "Líbia",
    "Morocco" : "Marrocos",
    "Moldova" : "Moldávia",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagascar",
    "Macedonia" : "Macedônia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongólia",
    "Mauritania" : "Mauritânia",
    "Malawi" : "Malawi",
    "Mexico" : "México",
    "Malaysia" : "Malásia",
    "Mozambique" : "Moçambique",
    "Namibia" : "Namíbia",
    "New Caledonia" : "Nova Caledônia",
    "Niger" : "Nigéria",
    "Nigeria" : "Nigéria",
    "Nicaragua" : "Nicarágua",
    "Netherlands" : "Holanda",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "New Zealand" : "Nova Zelândia",
    "Oman" : "Omã",
    "Panama" : "Panamá",
    "Peru" : "Peru",
    "Papua New Guinea" : "Papua Nova Guiné",
    "Philippines" : "Filipinas",
    "Pakistan" : "Paquistão",
    "Poland" : "Polônia",
    "Puerto Rico" : "Porto Rico",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguai",
    "Qatar" : "Catar",
    "Romania" : "Romênia",
    "Serbia" : "Sérvia",
    "Russia" : "Rússia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arábia Saudita",
    "Solomon Islands" : "Ilhas Salomão",
    "Sudan" : "Sudão",
    "Sweden" : "Suécia",
    "Singapore" : "Cingapura",
    "Slovenia" : "Eslovênia",
    "Slovakia" : "Eslováquia",
    "Sierra Leone" : "Serra Leoa",
    "Senegal" : "Senegal",
    "Somalia" : "Somália",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudão do Sul",
    "El Salvador" : "El Salvador",
    "Syria" : "Síria",
    "Swaziland" : "Suazilândia",
    "Chad" : "Chade",
    "Fr. S. Antarctic Lands" : "Fr. S. Terras Antárticas",
    "Togo" : "Togo",
    "Thailand" : "Tailândia",
    "Tajikistan" : "Tajiquistão",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turcomenistão",
    "Tunisia" : "Tunísia",
    "Turkey" : "Turquia",
    "Trinidad and Tobago" : "Trinidade e Tobago",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzânia",
    "Ukraine" : "Ucrânia",
    "Uganda" : "Uganda",
    "United States" : "Estados Unidos",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Uzbequistão",
    "Venezuela" : "Venezuela",
    "Vietnam" : "Vietnã",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Iêmen",
    "South Africa" : "África do Sul",
    "Zambia" : "Zâmbia",
    "Zimbabwe" : "Zimbábue",
    "Your Nextcloud account" : "Sua conta Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Seus dados representam quem você é e podem ser facilmente usados. Na Nextcloud acreditamos que você tem o direito de decidir o que acontece com eles. O Nextcloud protege seus direitos conforme definido no Manifesto de Dados do Usuário!",
    "User Data Manifesto 2.0" : "Manifesto de Dados do Usuário 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definindo direitos básicos para as pessoas controlarem seus próprios dados na era da internet",
    "Control" : "Controle",
    "over user data access" : "sobre o acesso a dados do usuário",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Os dados carregados explicitamente e de bom grado por um usuário devem estar sob o controle final dele. Os usuários podem decidir quem tem acesso direto aos dados e com quais permissões e licenças esse acesso deve ser concedido.",
    "Knowledge" : "Conhecimento",
    "of how the data is stored" : "de como os dados são armazenados",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Quando os dados são carregados em um provedor de serviços específico, os usuários devem ser informados sobre onde ele armazena os dados, por quanto tempo, em qual jurisdição o provedor de serviços específico opera e quais leis se aplicam.",
    "Freedom" : "Liberdade",
    "to choose a platform" : "escolher uma plataforma",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Os usuários podem extrair seus dados do serviço a qualquer momento sem qualquer bloqueio do fornecedor. Padrões abertos para formatos e protocolos são necessários para garantir isso.",
    "Learn more ↗" : "Saiba mais ↗",
    "Where is your data?" : "Onde estão seus dados?",
    "Who has access to your data?" : "Quem tem acesso aos seus dados?",
    "Administrators" : "Administradores",
    "People you shared with" : "Pessoas com quem você compartilhou",
    "Privacy policy" : "Política de privacidade",
    "Read the privacy policy." : "Leia a política de privacidade.",
    "Encryption" : "Criptografia"
},
"nplurals=2; plural=(n > 1);");
